## v0.2.0 (2025-03-25)

### Feat

- Adds better error handling for retriever and tool
- Implements GleanSearchRetriever and GleanSearchTool

### Fix

- Updating default for act_as to be empty string vs. None
- Ensure uv is executing python via venv
- Fixing imports (they were failing the check imports task
- Updating README.md to correct examples
- Fixing retriever type errors
- Fixing mypy errors
- Fixing actions workflows to use correct uv action
- Updating README.md and adding CONTRIBUTING.md
